@@ -1,8 +1,7 @@
 #! /bin/sh
 
-test -f /usr/sbin/laptop_mode || exit 0
+test -f /lib/udev/lmt-udev || exit 0
 
 # Automatically disable laptop mode when the battery almost runs out,
 # and re-enable it when it
-
-/usr/sbin/laptop_mode auto
+/lib/udev/lmt-udev
